@@ -135,9 +135,10 @@ class ShapleyLorenzShare:
             specifies, whether to plot a seperate graph for the
             class tuple, in case of multiple classes
         '''
+        lz_sorted = lz_shares[np.argsort(lz_shares[:,1])]
         if tuple == False:
-            plt.bar(lz_shares[:,0], lz_shares[:,1], color = (0.0,0.36,0.8,0.8))
-            plt.title('Shapley Lorenz Zonoid Values', fontweight = 'bold', fontsize = '14')
+            plt.bar(lz_sorted[:,0], lz_sorted[:,1], color = (0.0,0.36,0.8,0.8))
+            plt.title('Shapley Lorenz Zonoid Values', fontsize = '15')
             plt.ylabel('shapley LZ value')
             plt.xlabel('features')
             plt.show()
